# withcode
Offline python module to match visualisation and sound features of create.withcode.uk

Create.withcode.uk is designed for teachers and students to write, run, debug and share code on almost any device. 
It has a module designed to make it simple for students to explore how bitmap images can be displayed from pixel data

For example, you can use https://tools.withcode.uk/bitmap/ to generate the pixel data and python code for any image like this: https://create.withcode.uk/python/GWg

![image](https://user-images.githubusercontent.com/760604/154808133-9335c00c-6c19-4a21-8bb4-da0a145d5aea.png)

This module is designed to allow the same functionality as create.withcode.uk's withcode module with real 'offline' python
